/*
 *	Copyright (C) 2009 by Chebotarev Roman <roma@ultranet.ru>
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "informationwindow.h"

InformationWindow::InformationWindow(QWidget *parent, InformationTypes type,
					QString objectHttpLink, QString objectStatus,
					int autoCloseTime, QPoint leftCorner, bool stayOnTop)
    : QWidget(parent,
    		Qt::WindowSystemMenuHint | Qt::WindowTitleHint | Qt::SubWindow | Qt::MSWindowsFixedSizeDialogHint |
    		    		((stayOnTop)? Qt::WindowStaysOnTopHint : (Qt::WindowFlags) 0) )
{
	//setAttribute(Qt::WA_DeleteOnClose); 		// - -     :   
												//   .   
												// delete this;  closeEvent()
	ui.setupUi(this);

	ui.lbHostLink->setText(objectHttpLink);
	ui.lbStatus->setText(objectStatus);
	if(type == hostUp || type == hostDown)
		ui.lbObjectName->setText("  :");
	else
		ui.lbObjectName->setText("  :");
	ui.lbEventTime->setText(QDateTime::currentDateTime().toString("hh:mm:ss dd.MM.yyyy"));
	//  
	if(type == hostUp || type == serviceUp)
		setStyleSheet("QWidget { background: LimeGreen ; font-size: 10pt; font-weight: bold }");
	else
		setStyleSheet("QWidget { background: red ; font-size: 10pt; font-weight: bold; }");
	ui.lbHostLink->setStyleSheet("QLabel { font-size: 12pt; font-weight: bold;}");
	ui.cbAutoClose->setStyleSheet("QCheckBox { font-size: 8pt; font-weight: normal }");
	if(autoCloseTime)	//         
	{	//   
		timerAutoClose.setSingleShot(true);
		timerAutoClose.start(autoCloseTime * 1000 * 60); //   
		ui.cbAutoClose->setEnabled(true);
		ui.cbAutoClose->setChecked(true);
		//    close   
		connect(&timerAutoClose, SIGNAL(timeout()), this, SLOT(close()));
		//    " "      
		connect(ui.cbAutoClose, SIGNAL(toggled(bool)), this, SLOT(processCbAutoClose(bool)));
	}

	setWindowTitle("Nagios Agent:  ");
	setGeometry(leftCorner.rx(), leftCorner.ry(), width(), height());
	ui.lbHostLink->setFocus();	//   ,   
								//    /Return
	show();
}

void InformationWindow::processCbAutoClose(bool checked)
{
	timerAutoClose.stop();
	ui.cbAutoClose->setEnabled(checked);
}

InformationWindow::~InformationWindow()
{

}

void InformationWindow::closeEvent(QCloseEvent * event)
{
	//         
	deleteLater();	// .. setAttribute(Qt::WA_DeleteOnClose) -  
	event->accept();
}
